# User Guide

**This guide is aimed at developers who use otterdog to manage GitHub organizations and repositories via an existing otterdog setup.**

It focuses on the day-to-day workflow for making changes through configuration and pull requests, not on operating otterdog itself.

## Workflow for Changes

See [A typical GitHub workflow for making changes to your GitHub organization](workflow.md).


## Tutorials and Examples

The following guides provide concrete steps to perform in your otterdog configuration for common changes:

- [Adding Resources](adding.md) - Learn how to add new repositories to your GitHub organization using otterdog.
- [Removing Resources](removal.md) - Step-by-step guide on how to remove resources.
- [Renaming Resources](renaming.md) - How to rename resources without deleting and recreating them.

## Unsupported Features

Not all GitHub organization features and settings can be managed using `otterdog`.

Please refer to the [Unsupported Features](unsupported.md) guide for details on known limitations.
